@@ -282,17 +282,18 @@ impl Merge for Config {
             help,
             down,
             up,
+            open,
             all_down,
             all_up,
-            open,
+            kill_processes,
             selected,
             popup_border_style,
             help_key_style,
-            kill_processes,
-            commands,
-            esc_to_close,
-            exec_cmd
+            exec_cmd,
+            editor_cmd,
+            esc_to_close
         );
+        self.commands.merge(other.commands);
         self.special_commands.merge(other.special_commands);
         self.preview.merge(other.preview);
         self.filetree.merge(other.filetree);
@@ -1052,7 +1053,17 @@ impl fmt::Display for KeyBind {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match &self.0 {
             Either::Left(key) => write!(f, "{key}"),
-            Either::Right(keys) => write!(f, "{keys:?}"),
+            Either::Right(keys) => {
+                write!(f, "[")?;
+                for (i, key) in keys.iter().enumerate() {
+                    write!(f, "{key}")?;
+                    if i != keys.len() - 1 {
+                        write!(f, ", ")?;
+                    }
+                }
+                write!(f, "]")?;
+                Ok(())
+            }
         }
     }
 }
